@@ -84,8 +84,8 @@ def _synchronize_node(configfile):
     Uploads all cookbooks, all roles and all databags to a node and add the
     patch for data bags
 
-    Returns the node object of the node which is about to be configured, or None
-    if this node object cannot be found.
+    Returns the node object of the node which is about to be configured,
+    or None if this node object cannot be found.
     """
     print "Synchronizing node, cookbooks, roles and data bags..."
     # First upload node.json
@@ -120,6 +120,7 @@ def build_dct(dic, keys, value):
     else:
         dic[key] = value
 
+
 def update_dct(dic1, dic2):
     """Merges two dictionaries recursively
     dic2 will have preference over dic1
@@ -130,6 +131,10 @@ def update_dct(dic1, dic2):
             dic1.setdefault(key, {})
             update_dct(dic1[key], val)
         else:
+            if val == "false":
+                val = False
+            elif val == "true":
+                val = True
             dic1[key] = val
 
 
@@ -263,7 +268,7 @@ def _add_search_patch():
                 node_work_path, cookbook_paths[0], 'chef_solo_search_lib', 'libraries')
     with hide('running', 'stdout'):
         sudo('mkdir -p {0}'.format(lib_path))
-    # Create remote data bags patch
+    # Add search and environment patch to the node's cookbooks
     for filename in ('search.rb', 'parser.rb', 'environment.rb'):
         put(os.path.join(basedir, filename),
             os.path.join(lib_path, filename), use_sudo=True)
@@ -290,4 +295,3 @@ def _configure_node():
                 abort("")
         else:
             print(colors.green("\nSUCCESS: Node correctly configured"))
-
