@@ -47,7 +47,7 @@ def get_node(name):
     with open(node_path, 'r') as f:
         try:
             node = json.loads(f.read())
-        except json.decoder.JSONDecodeError as e:
+        except json.JSONDecodeError as e:
             msg = 'LittleChef found the following error in'
             msg += ' "{0}":\n                {1}'.format(node_path, str(e))
             abort(msg)
@@ -100,7 +100,7 @@ def get_recipes_in_cookbook(name):
             with open(os.path.join(path, 'metadata.json'), 'r') as f:
                 try:
                     cookbook = json.loads(f.read())
-                except json.decoder.JSONDecodeError as e:
+                except json.JSONDecodeError as e:
                     msg = "Little Chef found the following error in your"
                     msg += " {0}.json file:\n  {1}".format(
                         os.path.join(path, 'metadata.json'), e)
@@ -112,8 +112,7 @@ def get_recipes_in_cookbook(name):
                         'name': recipe,
                         'description': cookbook['recipes'][recipe],
                         'version': cookbook.get('version'),
-                        'dependencies': cookbook.get('dependencies',
-                                                        {}).keys(),
+                        'dependencies': cookbook.get('dependencies', {}).keys(),
                         'attributes': cookbook.get('attributes', {}),
                         })
                 # When a recipe has no default recipe (libraries?),
@@ -123,8 +122,7 @@ def get_recipes_in_cookbook(name):
                         'name': name,
                         'description': 'This cookbook has no default recipe',
                         'version': cookbook.get('version'),
-                        'dependencies': cookbook.get('dependencies',
-                                                        {}).keys(),
+                        'dependencies': cookbook.get('dependencies', {}).keys(),
                         'attributes': cookbook.get('attributes', {})
                     })
             # Cookbook metadata.json was found, don't try next cookbook path
@@ -202,7 +200,7 @@ def _get_role(rolename):
     with open(path, 'r') as f:
         try:
             role = json.loads(f.read())
-        except json.decoder.JSONDecodeError as e:
+        except json.JSONDecodeError as e:
             msg = "Little Chef found the following error in your"
             msg += " {0}.json file:\n  {1}".format(rolename, str(e))
             abort(msg)
@@ -222,6 +220,23 @@ def get_roles():
     return sorted(roles, key=lambda x: x['fullname'])
 
 
+def get_nodes_with_roles(rolename):
+    """ Get all nodes which include a given role,
+    prefix-searches are also supported
+    """
+    prefix_search = rolename.endswith("*")
+    if prefix_search:
+        rolename = rolename.rstrip("*")
+    for n in get_nodes():
+        if prefix_search:
+            roles = get_roles_in_node(n)
+            if any(role.startswith(rolename) for role in roles):
+                yield n
+        else:
+            if rolename in get_roles_in_node(n):
+                yield n
+
+
 def print_role(role, detailed=True):
     """Pretty prints the given role"""
     if detailed:
