@@ -23,7 +23,6 @@ from fabric.contrib.files import append, exists
 from fabric.contrib.console import confirm
 from paramiko.config import SSHConfig as _SSHConfig
 
-from littlechef.version import version
 from littlechef import solo
 from littlechef import lib
 from littlechef import chef
@@ -73,6 +72,12 @@ def new_kitchen():
             print "auth.cfg file created..."
 
 
+@hosts('setup')
+def nodes_with_role(rolename):
+    nodes = lib.get_nodes_with_roles(rolename)
+    return node(*[n['name'] for n in nodes])
+
+
 @hosts('setup')
 def node(*nodes):
     """Selects and configures a list of nodes. 'all' configures all nodes"""
@@ -108,7 +113,7 @@ def deploy_chef(gems="no", ask="yes", version="0.10",
     distro_type=None, distro=None, stop_client='yes'):
     """Install chef-solo on a node"""
     if not env.host_string:
-        abort('no node specified\nUsage: cook node:MYNODE deploy_chef')
+        abort('no node specified\nUsage: fix node:MYNODE deploy_chef')
     chef_versions = ["0.9", "0.10"]
     if version not in chef_versions:
         abort('Wrong Chef version specified. Valid versions are {0}'.format(
@@ -144,7 +149,7 @@ def recipe(recipe):
     """
     # Check that a node has been selected
     if not env.host_string:
-        abort('no node specified\nUsage: cook node:MYNODE recipe:MYRECIPE')
+        abort('no node specified\nUsage: fix node:MYNODE recipe:MYRECIPE')
     lib.print_header(
         "Applying recipe '{0}' on node {1}".format(recipe, env.host_string))
 
@@ -161,7 +166,7 @@ def role(role):
     """
     # Check that a node has been selected
     if not env.host_string:
-        abort('no node specified\nUsage: cook node:MYNODE role:MYROLE')
+        abort('no node specified\nUsage: fix node:MYNODE role:MYROLE')
     lib.print_header(
         "Applying role '{0}' to {1}".format(role, env.host_string))
 
@@ -231,10 +236,8 @@ def list_nodes_with_recipe(recipe):
 @hosts('api')
 def list_nodes_with_role(role):
     """Show all nodes which have asigned a given role"""
-    for node in lib.get_nodes():
-        recipename = 'role[' + role + ']'
-        if recipename in node.get('run_list'):
-            lib.print_node(node)
+    for node in lib.get_nodes_with_roles(role):
+        lib.print_node(node)
 
 
 @hosts('api')
@@ -350,7 +353,7 @@ def _readconfig():
 
 # Only read config if fix is being used and we are not creating a new kitchen
 import littlechef
-if littlechef.COOKING:
+if littlechef.__cooking__:
     # Called from command line
     if 'new_kitchen' not in sys.argv:
         _readconfig()
